@@ -31,6 +31,12 @@ CHANGELOG = ChangeLog(
         'Added greater support for code coverage',
         'Fixed numerous bugs via code coverage'
         ),
+    Version('0.3.4',
+        'Added better reference mechanics to context',
+        'Added rebinding of contexts to context referecnes',
+        'Added ability to set partial paths on contexts',
+        'Removed classcachedmethod as no good use case emerged for it',
+        ),
 )
 
 __doc__ += '\n' + str(CHANGELOG)
