@@ -18,7 +18,7 @@ from __version__ import *
 from bwobject import BWObject
 from bwmethod import (before_super, after_super, follow_super, filter_super,
                       override_super, around_super, override_result)
-from bwcached import cached, classcached, cachedmethod, classcachedmethod
+from bwcached import cached, classcached, cachedmethod
 from bwmember import member
 from bwthrowable import throw, catch, BWThrowable, TC
 
