@@ -76,7 +76,7 @@ __doc__, etc).  For @cached, simply access it through the class:
 '''
 
 from __version__ import *
-import types
+import types, sys
 
 class Volatile(object):
     __slots__ = ['obj']
@@ -265,48 +265,3 @@ def cachedmethod(fn, Volailte=Volatile):
     return cls()
 cachedmethod.volatile = Volatile
 
-def classcachedmethod(fn, Volailte=Volatile):
-    '''
-    Similar to @cachedmethod except works for classmethods like @classcached.
-
-    >>> class Value(object):
-    ...     def __init__(self, src):
-    ...         self.value = self.convert(src)
-    ...
-    ...     converter_name = None
-    ...     @classcachedmethod
-    ...     def convert(cls):
-    ...         if cls.converter_name is None:
-    ...             return classcachedmethod.volatile(lambda v: v)
-    ...         else:
-    ...             return getattr(cls, cls.converter_name)
-    ...
-    >>> class IntValue(Value):
-    ...     converter_name = 'to_int'
-    ...     @classmethod
-    ...     def to_int(cls, v):
-    ...         return int(v)
-    ...
-    >>> v = Value('Hello')
-    >>> v.value
-    'Hello'
-    >>> iv = IntValue('50')
-    >>> iv.value
-    50
-    '''
-
-    name = fn.__name__
-    def wrapper(self, target, cls=None):
-        target = cls or type(target)
-        obj = fn(target)
-        if type(obj) is not Volatile:
-            setattr(target, name, obj)
-            return obj
-        else:
-            return obj.obj
-    cls = type(fn.__name__,
-               (object,),
-               dict(__doc__=fn.__doc__, __get__=wrapper))
-    return cls()
-classcachedmethod.volatile = Volatile
-
